@@ -1,5 +1,5 @@
 ##
-# Copyright 2012-2013 Ghent University
+# Copyright 2009-2013 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -168,7 +168,8 @@ class EB_ALADIN(EasyBlock):
 
         aux_lib_gribex = os.path.join(tmp_installroot, gribdir, 'lib', 'libgribex.a')
         aux_lib_ibm = os.path.join(tmp_installroot, gribdir, 'lib', 'libibmdummy.a')
-        grib_api_lib = os.path.join(get_software_root('grib_api'), 'lib', 'libgrib_api_f90.a')
+        grib_api_lib = os.path.join(get_software_root('grib_api'), 'lib', 'libgrib_api.a')
+        grib_api_f90_lib = os.path.join(get_software_root('grib_api'), 'lib', 'libgrib_api_f90.a')
         grib_api_inc = os.path.join(get_software_root('grib_api'), 'include')
         jasperlib = os.path.join(get_software_root('JasPer'), 'lib', 'libjasper.a')
         netcdflib = os.path.join(get_software_root('netCDF'), 'lib', 'libnetcdff.a')
@@ -194,7 +195,8 @@ class EB_ALADIN(EasyBlock):
               'Please type the directory name where to find a dummy file mpif.h or ignore :': os.getenv('MPI_INC_DIR'),
               '%sthe library gribex or emos%s' % (qpref, qsuff2): aux_lib_gribex,
               '%sthe library ibm%s' % (qpref, qsuff): aux_lib_ibm,
-              '%sthe library grib_api_f90%s' % (qpref, qsuff): grib_api_lib,
+              '%sthe library grib_api%s' % (qpref, qsuff): grib_api_lib,
+              '%sthe library grib_api_f90%s' % (qpref, qsuff): grib_api_f90_lib,
               '%sthe JPEG auxilary library if enabled by Grib_api%s' % (qpref, qsuff2): jasperlib,
               '%sthe library netcdf%s' % (qpref, qsuff): netcdflib,
               '%sthe library lapack%s' % (qpref, qsuff): lapacklib,
