@@ -1,10 +1,5 @@
 ##
-# Copyright 2009-2012 Ghent University
-# Copyright 2009-2012 Stijn De Weirdt
-# Copyright 2010 Dries Verdegem
-# Copyright 2010-2012 Kenneth Hoste
-# Copyright 2011 Pieter De Baets
-# Copyright 2011-2012 Jens Timmerman
+# Copyright 2009-2013 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -29,6 +24,12 @@
 ##
 """
 EasyBuild support for building and installing the libsmm library, implemented as an easyblock
+
+@author: Stijn De Weirdt (Ghent University)
+@author: Dries Verdegem (Ghent University)
+@author: Kenneth Hoste (Ghent University)
+@author: Pieter De Baets (Ghent University)
+@author: Jens Timmerman (Ghent University)
 """
 
 import os
@@ -160,17 +161,8 @@ tasks=%(tasks)s
         else:
             self.log.error('No supported compiler found (tried GCC)')
 
-        # try and find BLAS lib
-        blas_found = False
-        blas_libs = ["ACML", "ATLAS", "IMKL"]
-        for blas_lib in blas_libs:
-            if get_software_root(blas_lib):
-                blas_found = True
-            else:
-                self.log.info("BLAS library %s not found" % blas_lib)
-
-        if not blas_found:
-            self.log.error('No known BLAS library found!')
+        if not os.getenv('LIBBLAS'):
+            self.log.error('No BLAS library specifications found (LIBBLAS not set)!')
 
         cfgdict = {
                    'datatype': None,
